==> e107-0.7.20.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum_viewtopic.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/forum/languages/English/lan_forum_viewtopic.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Forum");

define("LAN_01", "Forums");
define("LAN_02", "Go to page");
define("LAN_03", "Go");
define("LAN_04", "Previous");
define("LAN_05", "Next");
define("LAN_06", "Joined");
define("LAN_07", "Location");
define("LAN_08", "Website");
define("LAN_09", "Visits to site since registration");
define("LAN_10", "Back to top");
define("LAN_65", "Jump");
define("LAN_66", "This thread is now closed");
define("LAN_67", "Posts");
define("LAN_194", "Guest");
define("LAN_195", "Registered Member");
define("LAN_321", "Moderators: ");
define("LAN_389", "Previous thread");
define("LAN_390", "Next thread");
define("LAN_391", "Track Thread");
define("LAN_392", "Cancel Thread Tracking");
define("LAN_393", "Quick Reply");
define("LAN_394", "Preview");
define("LAN_395", "Reply To Thread");
define("LAN_396", "Website");
define("LAN_397", "Email");
define("LAN_398", "Profile");
define("LAN_399", "Private Message");
define("LAN_400", "Edit");
define("LAN_401", "Quote");

define("LAN_402", "Author");
define("LAN_403", "Post");
define("LAN_404", "No previous thread");
define("LAN_405", "No next thread");

define("LAN_406", "Moderator: Edit");
define("LAN_435", "Moderator: Delete");
define("LAN_408", "Moderator: Move");
define("LAN_409", "Are you sure you want to delete this thread and any replies?");
define("LAN_410", "Are you sure you want to delete this reply?");
define("LAN_411", "posted by ");

//v.616
define("LAN_412", "Title");
define("LAN_413", "Report");
define("LAN_414", "Report this thread to a moderator");
define("LAN_415", "Thread title");
define("LAN_416", "Enter your report");
define("LAN_417", "The admin will be made aware of this thread. You may post a message explaining what you found to be objectionable.");
define("LAN_418", "<b>Do not</b> use this form to contact the admin for any other reason.");
define("LAN_419", "Send Report");
define("LAN_420", "Click to view post");
define("LAN_421", "Forum thread report from");
define("LAN_422", "This post has been reported from site ");
define("LAN_423", "Message could not be sent. ");
define("LAN_424", "Post has been reported to moderator.<br />Thank You.");
define("LAN_425", "Message from: ");
define("LAN_426", "Reporting post in topic: ");
define("LAN_427", "Error sending mail");
define("LAN_428", "Post has been reported");
define("LAN_429", "Click here to return to forum");
define("LAN_430", "poll");
define("FORLAN_26", "Reply deleted");
define("FORLAN_10", "Begin New Thread");
define("LAN_29", "Edited");

define("LAN_431", "Syndicate this thread: rss 0.92");
define("LAN_432", "Syndicate this thread: rss 2.0");
define("LAN_433", "Syndicate this thread: RDF");

define("FORLAN_101", "Email Thread");
define("FORLAN_102", "Print View");
define('FORLAN_103', '[user deleted]');
define('FORLAN_104', 'Thread not found');
define("FORLAN_HIDDEN", "HIDDEN - LOGIN AND REPLY TO REVEAL");
?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum_viewtopic.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/forum/languages/English/lan_forum_viewtopic.php $
|     $Revision: 11678 $
|     $Id: lan_forum_viewtopic.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Forum");

define("LAN_01", "Forums");
define("LAN_02", "Go to page");
define("LAN_03", "Go");
define("LAN_04", "Previous");
define("LAN_05", "Next");
define("LAN_06", "Joined");
define("LAN_07", "Location");
define("LAN_08", "Website");
define("LAN_09", "Visits to site since registration");
define("LAN_10", "Back to top");
define("LAN_65", "Jump");
define("LAN_66", "This thread is now closed");
define("LAN_67", "Posts");
define("LAN_194", "Guest");
define("LAN_195", "Registered Member");
define("LAN_321", "Moderators: ");
define("LAN_389", "Previous thread");
define("LAN_390", "Next thread");
define("LAN_391", "Track Thread");
define("LAN_392", "Cancel Thread Tracking");
define("LAN_393", "Quick Reply");
define("LAN_394", "Preview");
define("LAN_395", "Reply To Thread");
define("LAN_396", "Website");
define("LAN_397", "Email");
define("LAN_398", "Profile");
define("LAN_399", "Private Message");
define("LAN_400", "Edit");
define("LAN_401", "Quote");

define("LAN_402", "Author");
define("LAN_403", "Post");
define("LAN_404", "No previous thread");
define("LAN_405", "No next thread");

define("LAN_406", "Moderator: Edit");
define("LAN_435", "Moderator: Delete");
define("LAN_408", "Moderator: Move");
define("LAN_409", "Are you sure you want to delete this thread and any replies?");
define("LAN_410", "Are you sure you want to delete this reply?");
define("LAN_411", "posted by ");

//v.616
define("LAN_412", "Title");
define("LAN_413", "Report");
define("LAN_414", "Report this thread to a moderator");
define("LAN_415", "Thread title");
define("LAN_416", "Enter your report");
define("LAN_417", "The admin will be made aware of this thread. You may post a message explaining what you found to be objectionable.");
define("LAN_418", "<b>Do not</b> use this form to contact the admin for any other reason.");
define("LAN_419", "Send Report");
define("LAN_420", "Click to view post");
define("LAN_421", "Forum thread report from");
define("LAN_422", "This post has been reported from site ");
define("LAN_423", "Message could not be sent. ");
define("LAN_424", "Post has been reported to moderator.<br />Thank You.");
define("LAN_425", "Message from: ");
define("LAN_426", "Reporting post in topic: ");
define("LAN_427", "Error sending mail");
define("LAN_428", "Post has been reported");
define("LAN_429", "Click here to return to forum");
define("LAN_430", "poll");
define("FORLAN_26", "Reply deleted");
define("FORLAN_10", "Begin New Thread");
define("LAN_29", "Edited");

define("LAN_431", "Syndicate this thread: rss 0.92");
define("LAN_432", "Syndicate this thread: rss 2.0");
define("LAN_433", "Syndicate this thread: RDF");

define("FORLAN_101", "Email Thread");
define("FORLAN_102", "Print View");
define('FORLAN_103', '[user deleted]');
define('FORLAN_104', 'Thread not found');
define("FORLAN_HIDDEN", "HIDDEN - LOGIN AND REPLY TO REVEAL");
?>
